@@ -1,4 +1,3 @@
-
 if [ -n "$MEE_ROOT" ]; then
 	export MEE_ROOT
 else
@@ -14,9 +13,9 @@ else
 fi
 
 if [ -n "$LD_LIBRARY_PATH" ]; then
-	export LD_LIBRARY_PATH="$MEE_ROOT/lib:$LD_LIBRARY_PATH"
+	export LD_LIBRARY_PATH="$MEE_ROOT/lib:$LD_LIBRARY_PATH:/opt/qtm12/lib"
 else
-	export LD_LIBRARY_PATH="$MEE_ROOT/lib"
+	export LD_LIBRARY_PATH="$MEE_ROOT/lib:/opt/qtm12/lib"
 fi
 
 if [ -n "$LD_PRELOAD" ]; then
@@ -25,3 +24,9 @@ else
 	export LD_PRELOAD="$MEE_ROOT/lib/libstdc++.so.6"
 fi
 
+
+if [ -n "$QML_IMPORT_PATH" ]; then
+	export QML_IMPORT_PATH="/opt/qtm12/imports:$QML_IMPORT_PATH"
+else
+	export QML_IMPORT_PATH="/opt/qtm12/imports"
+fi
